@@ -28,7 +28,7 @@ from kivy.core.window import Window  # pylint: disable=wrong-import-order
 from kivy.uix.textinput import TextInput  # pylint: disable=wrong-import-order
 
 MY_COMPUTER = "chris-mbp"
-SERVER = ["secureErase", MY_COMPUTER]
+SERVER = ["secureerase", MY_COMPUTER]
 
 if platform.node().lower() == MY_COMPUTER:
     config.DEBUG_CODE = True
