@@ -1,14 +1,17 @@
 import os
 import discord
+import platform
+import textwrap
 from discord.ext import commands
 from kivy.uix.button import Button
 from trello import TrelloClient
-from chatgpt import chatgpt
+import openai
 
 import shiny_api.modules.load_config as config
 from shiny_api.classes.ls_item import Item
 from shiny_api.modules.connect_ls import generate_ls_access
 
+
 print(f"Importing {os.path.basename(__file__)}...")
 
 COMMAND_PREFIX = "."
@@ -20,19 +23,19 @@ TRELLO_INVENYORY_LISTS = {
     "china": "63cd686b0de2bc0082b20499",
 }
 
+
 intents = discord.Intents.default()
 intents.members = True
 intents.message_content = True
 intents.presences = True
-bot = commands.Bot(command_prefix=COMMAND_PREFIX, intents=intents)
-chatgpt_client = chatgpt()
+client = commands.Bot(command_prefix=COMMAND_PREFIX, intents=intents)
 
 
-@bot.event
+@client.event
 async def on_ready():
-    print(f"{bot.user.display_name} has connected to Discord!")
+    print(f"{client.user.display_name} has connected to Discord!")
 
-    channels = bot.get_all_channels()
+    channels = client.get_all_channels()
 
     channel = discord.utils.get(channels, name="bot-config")
 
@@ -43,26 +46,92 @@ async def on_ready():
             await message.delete()
 
 
-@bot.event
+@client.event
 async def on_message(message: discord.Message):
-    if bot.user.mentioned_in(message):
-        await message.channel.send("RUFF!")
+    bots = client.guilds[0].members
+    if len(bots) > 1:
+        if platform.node().lower() == "secureerase":
+            return
+    if message.author == client.user:
+        return
 
-    await bot.process_commands(message)
+    if client.user.mentioned_in(message) or not message.guild:
+        prompt = message.content.replace(client.user.mention, "").strip()
+        engine = "text-davinci-003"
+        if prompt.split()[0].lower() == "code":
+            engine = "code-davinci-002"
+            prompt = " ".join(prompt.split()[1:]).strip()
+
+        if prompt.split()[0].lower() == "image":
+            image_engine = "image-alpha-001"
+            prompt = " ".join(prompt.split()[1:]).strip()
+            async with message.channel.typing():
+                await get_walle_image(message=message, engine=image_engine, prompt=prompt)
+        async with message.channel.typing():
+            await get_chatgpt_message(message=message, engine=engine, prompt=prompt)
+
+    await client.process_commands(message)
     if message.content is None or len(message.content) == 0:
         return
     if message.content[0] == COMMAND_PREFIX:
-        await message.delete()
+        # await message.delete()
+        pass
 
 
-@bot.command()
-async def chat(context, *, message: str):
-    response = chatgpt.get_response(message)
-    await context.send(response)
+async def get_walle_image(message: discord.Message, prompt: str, engine: str):
+    print(f"Sending message: {prompt} to {engine}")
+    try:
+        response = await openai.Image.acreate(
+            prompt=prompt, n=1, size="1024x1024", response_format="url", api_key=config.OPENAI_API_KEY
+        )
+    except openai.error.InvalidRequestError as exception:
+        await message.channel.send(str(exception))
+        return
+
+    image_url = response["data"][0]["url"]
+
+    embed = discord.Embed()
+    embed.set_image(url=image_url)
+
+    # Send the message
+    await message.channel.send(embed=embed)
 
 
-@bot.command()
+async def get_chatgpt_message(message: discord.Message, engine: str, prompt: str):
+    print(f"Sending message: {prompt} to {engine}")
+    try:
+        response = await openai.Completion.acreate(
+            engine=engine,
+            prompt=prompt,
+            max_tokens=1000,
+            n=1,
+            stop=None,
+            temperature=0.8,
+            api_key=config.OPENAI_API_KEY,
+        )
+    except openai.error.InvalidRequestError as exception:
+        await message.channel.send(str(exception))
+        return
+    await wrap_lines(response["choices"][0]["text"], message=message)
+    print(f"Received response: {response['choices'][0]['text']}")
+
+
+async def wrap_lines(lines: list[str], message: discord.Message):
+    lines = textwrap.wrap(lines, 2000, break_long_words=False, replace_whitespace=False)
+    for line in lines:
+        await message.channel.send(line)
+
+
+@client.command()
+async def testing(context: commands.Context, *args):
+    print(client.user)
+
+
+@client.command()
 async def ls(context: commands.Context, *args):
+    if context.channel.category_id != 896413039543336990:
+        await context.channel.send("Not allowed in this channel")
+        return
     if len(args) == 0 or args is None:
         return
     if args[0].lower() == "price" and len(args) > 1:
@@ -78,23 +147,26 @@ async def ls(context: commands.Context, *args):
         await context.channel.send(message_output)
 
 
-@bot.command()
+@client.command()
 async def trello(context: commands.Context, *args):
+    if context.channel.category_id != 896413039543336990:
+        await context.channel.send("Not allowed in this channel")
+        return
     if args is None or len(args) == 0:
         await trello_list_cards(TRELLO_INVENYORY_LISTS["pt"], context=context)
         return
 
     if len(args) > 1:
-        if args[0] == "list":
-            if args[1] not in TRELLO_INVENYORY_LISTS:
+        if args[0].lower() == "list":
+            if args[1].lower() not in TRELLO_INVENYORY_LISTS:
                 return
-            await trello_list_cards(list_id=TRELLO_INVENYORY_LISTS[args[1]], context=context)
+            await trello_list_cards(list_id=TRELLO_INVENYORY_LISTS[args[1].lower()], context=context)
             return
-        if args[0] == "add":
+        if args[0].lower() == "add":
             list_name = "pt"
             card_name = " ".join(args[1:])
-            if args[1] in TRELLO_INVENYORY_LISTS:
-                list_name = args[1]
+            if args[1].lower() in TRELLO_INVENYORY_LISTS:
+                list_name = args[1].lower()
             if len(args) > 2:
                 card_name = " ".join(args[2:])
             await trello_add_card(list_id=TRELLO_INVENYORY_LISTS[list_name], card_name=card_name)
@@ -122,27 +194,27 @@ async def trello_list_cards(list_id: int, context: commands.Context):
     return
 
 
-@bot.command()
+@client.command()
 async def clear(context: commands.Context, *args):
     if args[0].lower() == "bot":
         async for message in context.channel.history():
-            if message.author == bot.user:
+            if message.author == client.user and message.id != context.message.id:
                 await message.delete()
 
 
-@bot.command()
+@client.command()
 async def best(context: commands.Context, *args):
     if args is None:
         await context.channel.send(f"{context.author.mention} is the best!")
         return
-    users = bot.get_all_members()
+    users = client.get_all_members()
     for user in users:
         if " ".join(args).lower() in user.name.lower():
             await context.channel.send(f"{user.mention} is the best!")
 
 
 def start_bot(caller: Button):
-    bot.run(config.DISCORD_TOKEN)
+    client.run(config.DISCORD_TOKEN)
     caller.text = f"{caller.text.split(chr(10))[0]}\nDiscord Bot Running"
     caller.disabled = False
     caller.text = caller.text.split("\n")[0]
